@@ -9,7 +9,64 @@ no warnings 'redefine';
 
 use Pluto::Engine;
 
-sub core {
+my %seen;
+
+sub import {
+  my ($class, @args) = @_;
+
+  my $caller = caller;
+  return $class if $seen{$caller}++;
+
+  # handle file, hashref, and k/v pairs
+  my $config = (@args > 1 && !(scalar(@args) % 2)) ? {@args} : $args[0];
+
+  # config via env or import
+  unless (ref($config ||= $ENV{PLUTO_CONFIG})) {
+    $config = do $config if $config;
+  }
+
+  # create world engine
+  my $planet = Pluto::Engine->new(
+    package => "[$caller]",
+    config => config($config)
+  );
+
+  # call function
+  $planet->space->inject('call', sub {
+    $planet->call(@_);
+  });
+
+  # chain function
+  $planet->space->inject('chain', sub {
+    $planet->chain(@_);
+  });
+
+  # inc function
+  $planet->space->inject('inc', sub {
+    my ($name) = @_;
+    $planet->space->inject($name =~ s/\W//gr, sub {
+      $planet->call($name, @_);
+    });
+  });
+
+  # this function
+  $planet->space->inject('this', sub {
+    "[$caller]"
+  });
+
+  # service functions
+  for my $name (keys %{$planet->config}) {
+    unless ($planet->space->routine($name)) {
+      $planet->space->inject($name, sub {
+        $planet->services->process($name, @_);
+      });
+    }
+  }
+
+  return $class;
+}
+
+sub config {
   my ($config) = @_;
 
   {
@@ -56,55 +113,6 @@ sub core {
   }
 }
 
-my %seen;
-
-sub import {
-  my ($class, @args) = @_;
-
-  my $caller = caller;
-  return $class if $seen{$caller}++;
-
-  # handle file, hashref, and k/v pairs
-  my $config = (@args > 1 && !(scalar(@args) % 2)) ? {@args} : $args[0];
-
-  # config via env or import
-  unless (ref($config ||= $ENV{PLUTO_CONFIG})) {
-    $config = do $config if $config;
-  }
-
-  # create world engine
-  my $planet = Pluto::Engine->new(package => "[$caller]", config => core($config));
-
-  # call function
-  $planet->space->inject('call', sub {
-    $planet->call(@_);
-  });
-
-  # chain function
-  $planet->space->inject('chain', sub {
-    $planet->chain(@_);
-  });
-
-  # inc function
-  $planet->space->inject('inc', sub {
-    my ($name) = @_;
-    $planet->space->inject($name =~ s/\W//gr, sub {
-      $planet->call($name, @_);
-    });
-  });
-
-  # service functions
-  for my $name (keys %{$planet->config}) {
-    unless ($planet->space->routine($name)) {
-      $planet->space->inject($name, sub {
-        $planet->services->process($name, @_);
-      });
-    }
-  }
-
-  return $class;
-}
-
 1;
 =encoding utf8
 
