@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 use Data::Object::Space;
 use Rewire;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # ATTRIBUTES
 
@@ -59,29 +59,6 @@ fun new_space($self) {
   Data::Object::Space->new($self->package);
 }
 
-# BUILD
-
-my %seen;
-
-fun BUILD($self, $args) {
-  my $space = $self->space;
-
-  if ($seen{$space->package}++) {
-    return $self;
-  }
-
-  # defaults
-  $space->eval('use strict');
-  $space->eval('use warnings');
-  $space->eval('use Type::Library -base');
-
-  # types and signatures
-  $space->use('registry', $space->package);
-  $space->use('routines');
-
-  return $self;
-}
-
 # METHODS
 
 method call(Str | Object $invocant, Str $routine, Any @arguments) {
